@@ -26,29 +26,15 @@ REQUIRED_CONFIG_KEYS = [
     'password'
 ]
 
+
 # 命令: tap-mysql -c config.json --discover
 # def do_discover(mysql_conn, config):
 #     discover_catalog(mysql_conn, config.get('filter_dbs')).dump()
+
 # 重构以此方法
 def do_discover(mysql_conn, config):
-    print("*****************************************************************************")
-    print(mysql_conn, config)
-    print("*****************************************************************************")
-    from kafka import KafkaProducer
-    import json
-    to_kafka_msg = discover_catalog(mysql_conn, config.get('filter_dbs')).dump()
-    print("*****************************************************************************")
+    to_kafka_msg = discover_catalog(mysql_conn, config.get('filter_dbs')).to_dict()
     jjy_custom_singer_write_message(to_kafka_msg, config=config, method="do_discover")
-    # kafka_ip = config.get("kafka_ip")
-    # kafka_port = config.get("kafka_port")
-    # kafka_topic = config.get("kafka_topic")
-    # producer = KafkaProducer(
-    #     value_serializer=lambda v: json.dumps(v).encode('utf-8'),
-    #     bootstrap_servers=[f'{kafka_ip}:{kafka_port}']
-    # )
-    # producer.send(kafka_topic, to_kafka_msg)
-    # producer.close()
-
 
 
 def log_engine(mysql_conn, catalog_entry):
@@ -383,7 +369,6 @@ def sync_non_binlog_streams(mysql_conn, non_binlog_catalog, state, use_gtid, eng
 
 
 def sync_binlog_streams(mysql_conn, binlog_catalog, config, state):
-
     if binlog_catalog.streams:
         for stream in binlog_catalog.streams:
             write_schema_message(stream, config=config)
@@ -394,7 +379,6 @@ def sync_binlog_streams(mysql_conn, binlog_catalog, config, state):
 
 
 def do_sync(mysql_conn, config, catalog, state):
-
     config['use_gtid'] = config.get('use_gtid', False)
     config['engine'] = config.get('engine', MYSQL_ENGINE).lower()
 
